import express, { Request, Response } from "express";
import {
  getCalendarItemById,
  getAllCalendarItems,
  getAllCalendarTypes,
  getCalendarTypeById,
  createCalendarItem,
  createCalendarType,
  updateCalendarItem,
  updateCalendarType,
  deleteCalendarItem,
  deleteCalendarType,
} from "../../controller/admin/calendarController";
import PermissionHelper from "../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get(
  "/items",
  PermissionHelper.passCheckMiddleware("read", "club", "calendar"),
  async (req: Request, res: Response) => {
    await getAllCalendarItems(req, res);
  }
);

router.get(
  "/item/:id",
  PermissionHelper.passCheckMiddleware("read", "club", "calendar"),
  async (req: Request, res: Response) => {
    await getCalendarItemById(req, res);
  }
);

router.get(
  "/types",
  PermissionHelper.passCheckMiddleware("read", "settings", "calendar_type"),
  async (req: Request, res: Response) => {
    await getAllCalendarTypes(req, res);
  }
);

router.get(
  "/type/:id",
  PermissionHelper.passCheckMiddleware("read", "settings", "calendar_type"),
  async (req: Request, res: Response) => {
    await getCalendarTypeById(req, res);
  }
);

router.post(
  "/item",
  PermissionHelper.passCheckMiddleware("create", "club", "calendar"),
  async (req: Request, res: Response) => {
    await createCalendarItem(req, res);
  }
);

router.post(
  "/type",
  PermissionHelper.passCheckMiddleware("create", "settings", "calendar_type"),
  async (req: Request, res: Response) => {
    await createCalendarType(req, res);
  }
);

router.patch(
  "/item/:id",
  PermissionHelper.passCheckMiddleware("update", "club", "calendar"),
  async (req: Request, res: Response) => {
    await updateCalendarItem(req, res);
  }
);

router.patch(
  "/type/:id",
  PermissionHelper.passCheckMiddleware("update", "settings", "calendar_type"),
  async (req: Request, res: Response) => {
    await updateCalendarType(req, res);
  }
);

router.delete(
  "/item/:id",
  PermissionHelper.passCheckMiddleware("delete", "club", "calendar"),
  async (req: Request, res: Response) => {
    await deleteCalendarItem(req, res);
  }
);

router.delete(
  "/type/:id",
  PermissionHelper.passCheckMiddleware("delete", "settings", "calendar_type"),
  async (req: Request, res: Response) => {
    await deleteCalendarType(req, res);
  }
);

export default router;
